@@ -207,7 +207,7 @@ sub _update_dir {
 
 sub import {
     my $self = shift;
-    return unless @_;
+    return unless ref $self; # get rid of class->import
     return $self->SUPER::import( @_, delete => 1 );
 }
 
